@@ -219,6 +219,7 @@ init_local_props local.properties || { echo "Error initializing local.properties
 if [ ! -d "$ANDROID_SDK/licenses" ]; then
     mkdir "$ANDROID_SDK/licenses"
     echo "8933bad161af4178b1185d1a37fbf41ea5269c55" > "$ANDROID_SDK/licenses/android-sdk-license"
+    echo "d56f5187479451eabf01fb78af6dfcb131a6481e" >> "$ANDROID_SDK/licenses/android-sdk-license"
     echo "84831b9409646a918e30573bab4c9c91346d8abd" > "$ANDROID_SDK/licenses/android-sdk-preview-license"
 fi
 
@@ -226,10 +227,10 @@ fi
 # Fetch VLC source #
 ####################
 
-TESTED_HASH=35acae8
+TESTED_HASH=775d32f
 if [ ! -d "vlc" ]; then
     diagnostic "VLC source not found, cloning"
-    git clone http://git.videolan.org/git/vlc.git vlc
+    git clone https://git.videolan.org/git/vlc/vlc-3.0.git vlc
     checkfail "vlc source: git clone failed"
 fi
 diagnostic "VLC source found"
