@@ -9,32 +9,39 @@ import java.util.List;
 
 public class Playlist extends MediaLibraryItem {
 
-    protected Playlist(long id, String name) {
+    private int mTracksCount;
+
+    protected Playlist(long id, String name, int trackCount) {
         super(id, name);
+        mTracksCount = trackCount;
     }
 
-    protected Playlist(Parcel in) {
-        super(in);
-    }
-
-    public MediaWrapper[] getTracks(Medialibrary ml) {
+    public MediaWrapper[] getTracks() {
+        Medialibrary ml = Medialibrary.getInstance();
         return ml != null && ml.isInitiated() ? nativeGetTracksFromPlaylist(ml, mId) : Medialibrary.EMPTY_COLLECTION;
     }
 
+    public int getTracksCount() {
+        return mTracksCount;
+    }
+
     @Override
     public int getItemType() {
         return TYPE_PLAYLIST;
     }
 
-    public boolean append(Medialibrary ml, long mediaId) {
+    public boolean append(long mediaId) {
+        Medialibrary ml = Medialibrary.getInstance();
         return ml != null && ml.isInitiated() && nativePlaylistAppend(ml, mId, mediaId);
     }
 
-    public boolean append(Medialibrary ml, long[] mediaIds) {
+    public boolean append(long[] mediaIds) {
+        Medialibrary ml = Medialibrary.getInstance();
         return ml != null && ml.isInitiated() && nativePlaylistAppendGroup(ml, mId, mediaIds);
     }
 
-    public boolean append(Medialibrary ml, List<Long> mediaIds) {
+    public boolean append(List<Long> mediaIds) {
+        Medialibrary ml = Medialibrary.getInstance();
         if (ml == null || !ml.isInitiated())
             return false;
         long[] ids = new long[mediaIds.size()];
@@ -43,19 +50,23 @@ public class Playlist extends MediaLibraryItem {
         return nativePlaylistAppendGroup(ml, mId, ids);
     }
 
-    public boolean add(Medialibrary ml, long mediaId, int position) {
+    public boolean add(long mediaId, int position) {
+        Medialibrary ml = Medialibrary.getInstance();
         return ml != null && ml.isInitiated() && nativePlaylistAdd(ml, mId, mediaId, position);
     }
 
-    public boolean move(Medialibrary ml, long mediaId, int position) {
+    public boolean move(long mediaId, int position) {
+        Medialibrary ml = Medialibrary.getInstance();
         return ml != null && ml.isInitiated() && nativePlaylistMove(ml, mId, mediaId, position);
     }
 
-    public boolean remove(Medialibrary ml, long mediaId) {
+    public boolean remove(long mediaId) {
+        Medialibrary ml = Medialibrary.getInstance();
         return ml != null && ml.isInitiated() && nativePlaylistRemove(ml, mId, mediaId);
     }
 
-    public boolean delete(Medialibrary ml) {
+    public boolean delete() {
+        Medialibrary ml = Medialibrary.getInstance();
         return ml != null && ml.isInitiated() && nativePlaylistDelete(ml, mId);
     }
 
@@ -70,6 +81,17 @@ public class Playlist extends MediaLibraryItem {
         }
     };
 
+    @Override
+    public void writeToParcel(Parcel parcel, int i) {
+        super.writeToParcel(parcel, i);
+        parcel.writeInt(mTracksCount);
+    }
+
+    private Playlist(Parcel in) {
+        super(in);
+        this.mTracksCount = in.readInt();
+    }
+
     private native MediaWrapper[] nativeGetTracksFromPlaylist(Medialibrary ml, long id);
     private native boolean nativePlaylistAppend(Medialibrary ml, long id, long mediaId);
     private native boolean nativePlaylistAppendGroup(Medialibrary ml, long id, long[] mediaIds);
